pub struct Boolean { /* private fields */ }Expand description
An index that provide any & all queries for boolean inputs.
Implementations
Sourceimpl Boolean
impl Boolean
pub fn new() -> Self
Sourcepub fn all(&self) -> bool
pub fn all(&self) -> bool
Returns true if all indexed values are true (or if the collection is empty).
An empty collection returns true (vacuous truth).
Sourcepub fn any(&self) -> bool
pub fn any(&self) -> bool
Returns true if at least one indexed value is true.
An empty collection returns false.
Sourcepub fn true_count(&self) -> usize
pub fn true_count(&self) -> usize
Returns the count of true values.
Sourcepub fn false_count(&self) -> usize
pub fn false_count(&self) -> usize
Returns the count of false values.
Sourcepub fn total_count(&self) -> usize
pub fn total_count(&self) -> usize
Returns the total count of all values (both true and false).